Learn R Programming

pks (version 0.8-0)

hsgeometry: Responses to Geometry Problems and Knowledge Structures

Description

Lakshminarayan (1995, 1996) presented high school geometry problems to 959 undergraduate students before and after a lesson. The problems deal with basic concepts in geometry, such as angles, lengths, circles, and polygons. Doignon and Falmagne (1999, chap. 8) refer to a subset of these data.

Usage

data(hsgeometry)

Arguments

Format

Two lists, each consisting of three components:

angles

a list with components K, N.R, and changescore for five problems mostly about angles.

circles

a list with components K, N.R, and changescore for four problems mostly about circles.

K

a state-by-problem indicator matrix representing the knowledge structure in Lakshminarayan (1995, 1996).

N.R

a matrix. The row names denote response patterns, the column entries their frequencies before and after the lesson.

changescore

a 3d table. For each problem, it contains the number of students who solved or did not solve the problem at pre- and posttest.

References

Doignon, J.-P., & Falmagne, J.-C. (1999). Knowledge spaces. Berlin: Springer.

Lakshminarayan, K. (1995). Theoretical and empirical aspects of some stochastic learning models. Doctoral dissertation. University of California, Irvine.

Examples

Run this code
data(hsgeometry)
dotchart(angles$N.R[, "posttest"], pch = 4,
         main = "High school geometry problems",
         xlab = "Response frequency (pre- [o] and posttest [x])")
points(angles$N.R[, "pretest"], 1:32)
mtext("Lakshminarayan (1995)", side = 3, line = 0.5)

Run the code above in your browser using DataLab