| hsgeometry | R Documentation |
Lakshminarayan (1995, 1996) presented high school geometry problems to 959 undergraduate students before and after a lesson. The problems deal with basic concepts in geometry, such as angles, lengths, circles, and polygons. Doignon and Falmagne (1999, chap. 8) refer to a subset of these data.
data(hsgeometry)
Two lists, each consisting of three components:
anglesa list with components K, N.R, and
changescore for five problems mostly about angles.
circlesa list with components K, N.R, and
changescore for four problems mostly about circles.
Ka state-by-problem indicator matrix representing the knowledge structure in Lakshminarayan (1995, 1996).
N.Ra matrix. The row names denote response patterns, the column entries their frequencies before and after the lesson.
changescorea 3d table. For each problem, it contains the number of students who solved or did not solve the problem at pre- and posttest.
Only those 800 responses used to estimate the model parameters are reported (the held-out sample is missing).
Thanks to Kamakshi Lakshminarayan, Cord Hockemeyer, and Mike Regenwetter for their help with finding the data.
Lakshminarayan, K (1996). A hybrid latent trait and latent class model of learning - Theoretical details and empirical application. Technical report No. MBS 96-07. University of Califomia, Irvine.
Doignon, J.-P., & Falmagne, J.-C. (1999). Knowledge spaces. Berlin: Springer.
Lakshminarayan, K. (1995). Theoretical and empirical aspects of some stochastic learning models. Doctoral dissertation. University of California, Irvine.
data(hsgeometry)
dotchart(angles$N.R[, "posttest"], pch = 4,
main = "High school geometry problems",
xlab = "Response frequency (pre- [o] and posttest [x])")
points(angles$N.R[, "pretest"], 1:32)
mtext("Lakshminarayan (1995)", side = 3, line = 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.